@@ -5,6 +5,11 @@ class TincBackend(object):
     def __init__(self, obj):
         self.obj = obj
     
+    @classmethod
+    def reverse(cls, ip_addr):
+        from .utils import reverse
+        return reverse(ip_addr)
+    
     @property
     def name(self):
         return self.obj.tinc._meta.verbose_name.replace(' ', '_')
@@ -13,6 +18,10 @@ class TincBackend(object):
     def addr(self):
         return self.obj.tinc.address
     
+    @property
+    def native(self):
+        return None
+    
     def tinc_client(self):
         return self.obj.tinc if self.name == 'tinc_client' else None
     
@@ -21,7 +30,3 @@ class TincBackend(object):
     
     def is_configured(self):
         return bool(self.obj.tinc.pubkey)
-    
-    @property
-    def native(self):
-        return None
